<?php

if ( ! defined( 'ABSPATH' ) ) {
  die( '-1' );
}

/**
 * Create or Update, Script or Upload Banner Type
 * @param $post
 */
function bc_rb_create_update_upload_script($post){
  if (isset($post['file_url_link']) && isset($post['banner_type'])) {
    $content = array();
    if($post['banner_type'] == 'upload'){
      $content['file_url_link'] = esc_url($post['file_url_link']);
      $content['file_description'] = isset($post['file_description']) ? esc_attr($post['file_description']) : '';
      $content['external_link'] = isset($post['external_link']) ? esc_url($post['external_link']) : '';
      $content['width'] = isset($post['width']) ? intval($post['width']) : '';
      $content['height'] = isset($post['height']) ? intval($post['height']) : '';
      $content['automatic'] = isset($post['automatic']) ? esc_attr($post['automatic']) : '';
    }

    if($post['banner_type'] == 'script'){
      $content['file_url_link'] = ($post['file_url_link']);
    }
    $content['category'] = isset($post['category']) ? esc_attr($post['category']) : 'default';
    $content['banner_id'] = isset($post['banner_id']) ? (int)esc_attr($post['banner_id']) : 'no';
    $content['banner_type'] = esc_attr($post['banner_type']);

    // Add new banner to table
    if ($content['banner_id'] == 'no') {
      $db_status = bc_rb_create($content);
      populate_data($db_status, 'Successfully Added');
    } else { // Update the banner with ID
      $db_status = bc_rb_update($content);
      populate_data($db_status, 'Successfully Updated');
    }
  }
}

/**
 * Delete Upload or Script by ID
 * @param $post
 */
function bc_rb_delete_upload_script($post){
  if (isset($post['banner_id'])) {
    $content = array();
    $content['banner_id'] = (int) $post['banner_id'];
    $verify = bc_rb_delete_by_id($content['banner_id']);
    if ($verify == 'success') {
      echo json_encode(array('message' => 'Successfully Deleted ' . esc_attr($post['file_description']), 'type' => 'success'));
      die();
    }
  }
  echo json_encode(array('error' => 'Something went wrong, Please try again', 'type' => 'error'));
  die();
}

/**
 * Save setting options
 */
function bc_rb_save_setting_options($post)
{
  // Setting Default Value to not to brake array_intersect_key
  if (!isset($post['bc_rb_setting_options'])) {
    $post = array('bc_rb_setting_options' => array('open' => ''));
  }
  // Default Values
  $array_key = array('bc_rb_setting_options' => array('open' => ''));

  // Intersect and get only required post value
  $value = array_intersect_key($post['bc_rb_setting_options'], $array_key['bc_rb_setting_options']);

  update_option('bc_rb_setting_options', serialize($value));
  echo 'ok';
  die();
}


/**
 * Create or Update Category
 * @param $post
 */
function bc_rb_create_update_category($post){

  $category = bc_rb_add_update_category($post);

  if($category == 'already_exist'){
    echo json_encode(array('message'=>'Category name already exist, Please add different name','type'=>'error'));
    exit();
  }
  if($category == 'new_row_created'){
    bc_rb_populate_category();
  }

  echo json_encode(array('message'=>'Something went wrong, please try again later','type'=>'error'));
  exit();

}

function bc_rb_delete_category_id($post)
{
  if (isset($post['category']) && isset($post['category_id'])) {
    $verify = bc_rb_delete_category_by_id($post);
    if ($verify == 'success') {
      echo json_encode(array('message' => 'Successfully Deleted ' . esc_attr($post['category']), 'type' => 'success'));
      die();
    }
  }
  echo json_encode(array('error' => 'Something went wrong, Please try again', 'type' => 'error'));
  die();
}

function bc_rb_validate_account($post){

  if(isset($post['domain']) && isset($post['transaction_id'])){
    $transaction_id = esc_attr($post['transaction_id']);
    $domain = esc_attr($post['domain']);

  $url = 'http://ifecho.com/api/random_banner/'.$transaction_id.'/'.$domain;

    $response = wp_remote_get($url, array('timeout' => 120, 'httpversion' => '1.1'));
    if (is_array($response)) {
      $value = json_decode($response['body']);
      if($value->status == 'ok'){
        update_option('bc_rb_payment_info',$value->transaction_id);
        echo json_encode(array('status'=>'ok','message' => 'Successfully your transaction has been verified', 'type' => 'success'));
        exit();
      }
    }
  }
  echo json_encode(array('status'=>'no','message' => 'Invalid Transaction Details, Please try again', 'type' => 'error'));
  exit();

}

